/*
 *
 * PSX Controller Detect v1.0 17/07/99 Richard Davies 
 * <mailto:richard@debaser.force9.co.uk>
 *
 * Revision History:
 * v1.0 - 17/07/99 Initial Release.
 *
 */



#include <stdlib.h>
#include <stdio.h>
#include "psxpblib.h"
#include "psxpbcfg.h"



int main(int argc, char *argv[])
{

   int base, conport, tap, delay, nothing, psx_type;
   
   printf("PSX Controller Detect v1.0 17/07/99 Richard Davies\n");
   printf("<mailto:richard@debaser.force9.co.uk>\n\n");
   
   printf("Use: psxcnd [-lpt (1..3)] [-del (1..%d)]\n", PSX_MAX_DELAY);
   printf("Settings also held in 'psxpblib.cfg'\n\n");

   base = -1;
   delay = 3;

   psxpb_cfg(&base, &nothing, &nothing, &delay);
   
   psxpb_cmd(&base, &nothing, &nothing, &delay, argc, argv);
   
   /* check parameters */
   if (base == -1)
   {
      printf("Error! You need to specify which parallel port to use!\n");
      return;
   }
   
   /* report parameters */
   printf("Parallel port: base 0x%x\n", base); 
   printf("Scan delay: %d\n\n", delay);

   printf("Any key to continue...\n\n");
   if (getch() == 27)
   {
      return;
   }

   printf("Scanning parallel port base 0x%x:\n", base);

   /* for each possible conport... */
   for (conport = 1; conport <= PSX_MAX_CONPORTS; conport++)
   {
      /* and each possible controller attached (2-4 are Multi tap) */
      for (tap = 1; tap <= PSX_MAX_TAPS; tap++)
      {
         psx_type = psx_controller_detect(base, conport, tap, delay);

         if (psx_type != -1)
         {
            printf("%d%c ", conport, tap + ('A' - 1));

            switch(psx_type)
            {
               case PSX_MOUSE:
                  printf("Mouse\n");
                  break;
               case PSX_NEGCON:
                  printf("Namco neGcon\n");
                  break;
               case PSX_KONAMIGUN:
                  printf("Konami Lightgun\n");
                  break;
               case PSX_DIGITAL:
                  printf("Digital\n");
                  break;
               case PSX_ANALOG_GREEN:
                  printf("Analog\n");
                  break;
               case PSX_GUNCON:
                  printf("Namco G-con45\n");
                  break;
               case PSX_ANALOG_RED:
                  printf("Dual Shock Analog\n");
                  break;
               case PSX_JOGCON:
                  printf("Namco Jogcon\n");
                  break;
               default:
                  printf("Unknown Device %d\n", psx_type);
                  break;
            }       
         }
      }
   }
   
   return;
}
