/*
 *
 * PSX Controller Test v1.2 17/07/99 Richard Davies 
 * <mailto:richard@debaser.force9.co.uk>
 *
 * Revision History:
 * v1.2 - 17/07/99 Now using PSX Peripheral Bus Library v1.0 17/07/99, by me.
 * v1.1 - 22/06/99 Rewritten, added Multi tap, Mouse, G-con45, Konami Gun, Jogcon and
 *                 unsupported controllers.
 * v1.0 - 06/06/99 Initial release.
 *
 */



#include <stdlib.h>
#include <stdio.h>
#include "psxpblib.h"
#include "psxpbcfg.h"



void show_binary_byte(byte)
{
   printf("%1d", byte&0x80?1:0);
   printf("%1d", byte&0x40?1:0);
   printf("%1d", byte&0x20?1:0);
   printf("%1d", byte&0x10?1:0);
   printf("%1d", byte&0x08?1:0);
   printf("%1d", byte&0x04?1:0);
   printf("%1d", byte&0x02?1:0);
   printf("%1d ", byte&0x01?1:0);
}



int main(int argc, char *argv[])
{
   int base, conport, tap, delay, nothing, i, detected, last_detected = 0;
   char key = '0';
   PSX_CON_BUF* psx_con_buf;
   
   printf("PSX Controller Test v1.2 17/07/99 Richard Davies\n");
   printf("<mailto:richard@debaser.force9.co.uk>\n\n");

   printf("Use: psxcnt [-lpt (1..3)] [-del (1..%d)]\n", PSX_MAX_DELAY);
   printf("Settings also held in 'psxpblib.cfg'\n\n");

   base = -1;
   delay = 3;

   psxpb_cfg(&base, &nothing, &nothing, &delay);
   
   psxpb_cmd(&base, &nothing, &nothing, &delay, argc, argv);
   
   /* check parameters */
   if (base == -1)
   {
      printf("Error! You need to specify which parallel port to use!\n");
      return;
   }
   
   /* report parameters */
   printf("Parallel port: base 0x%x\n", base); 
   printf("Scan delay: %d\n\n", delay);

   printf("Any key to continue...\n\n");
   if (getch() == 27)
   {
      return;
   }

   ScreenClear();
   
   /* Send Jogcon init to all controllers */
   /* for each possible conport... */
   for (conport = 1; conport <= PSX_MAX_CONPORTS; conport++)
   {
      /* and each possible controller attached (2-4 are Multi tap) */
      for (tap = 1; tap <= PSX_MAX_TAPS; tap++)
      {
         if (psx_controller_detect(base, conport, tap, delay) != -1)
         {
            psx_controller_vinit(base, conport, tap, delay); 
         }
      }
   }

   while(1)
   {
      detected = 0;
      
      ScreenSetCursor( 0, 0 );
      	 
      printf("Scanning parallel port base 0x%x:\n", base);

      /* for each possible conport... */
      for (conport = 1; conport <= PSX_MAX_CONPORTS; conport++)
      {      	 
         /* and each possible controller attached (2-4 are Multi tap) */
         for (tap = 1; tap <= PSX_MAX_TAPS; tap++)
         {
            psx_con_buf =  psx_controller_read(base, conport, tap, delay);
     
            if (psx_con_buf != NULL)
            {
               detected++;
               
               printf("%d%c ", conport, tap + ('A' - 1));
          
               for (i = 0; i < psx_con_buf->length; i++)
                  show_binary_byte(psx_con_buf->data[i]);

               switch(psx_con_buf->type)
               {
                  case PSX_MOUSE:
                     printf("Mouse\n");
                     break;
                  case PSX_NEGCON:
                     printf("Namco neGcon\n");
                     break;
                  case PSX_KONAMIGUN:
                     printf("Konami Lightgun\n");
                     break;
                  case PSX_DIGITAL:
                     printf("Digital\n");
                     break;
                  case PSX_ANALOG_GREEN:
                     printf("Analog\n");
                     break;
                  case PSX_GUNCON:
                     printf("Namco G-con45\n");
                     break;
                  case PSX_ANALOG_RED:
                     printf("Dual Shock Analog ");
                     if (key == '1')
                     {
                        printf("!\n");
               	  
                        while (key == '1')
                        {
                           psx_controller_vshock(base, conport, tap, delay, 0xff, 0); 

                           if (kbhit())
                              key = getch();
                           else
                              key = '0';
                        }
                  
                        if (kbhit())
                           key = getch();
                        else key = '0';                  
                     }
                     else if (key == '2')
                     {
                        printf("!!\n");
               	  
                        while (key == '2')
                        {
                           psx_controller_vshock(base, conport, tap, delay, 0, 0xff); 

                           if (kbhit())
                              key = getch();
                           else
                              key = '0';
                        }
                  
                        if (kbhit())
                           key = getch();
                        else key = '0';                  
                     }
                     else if (key == '3')
                     {
                        printf("!!!\n");
               	  
                        while (key == '3')
                        {
                           psx_controller_vshock(base, conport, tap, delay, 0xff, 0xff); 

                           if (kbhit())
                              key = getch();
                           else
                              key = '0';
                        }
                  
                        if (kbhit())
                           key = getch();
                        else key = '0';                  
                     }
                     else
                        printf("   \n");
                     break;
                  case PSX_JOGCON:
                     printf("Namco Jogcon\n");
                     break;
                  default:
                     printf("Unknown Device %d\n", psx_con_buf->type);
                     break;
               }
            }
         }
      }
      
      if (detected != last_detected)
         ScreenClear();

      if (kbhit())
      {                        
         key = getch();
              	            
         if (key == 27)
         {
            ScreenSetCursor(detected + 1, 0);
            break;
         }
      }
      
      last_detected = detected;
   }
}
